<?php
namespace Aws\GameLiftStreams\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon GameLift Streams** service.
 */
class GameLiftStreamsException extends AwsException {}
